==> zio-aws-ec2_2.13-5.17.124.3-sources.jar: zio/aws/ec2/model/NetworkInterfaceIpv6Address.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class NetworkInterfaceIpv6Address(
    ipv6Address: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address = {
    import NetworkInterfaceIpv6Address.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
      .builder()
      .optionallyWith(ipv6Address.map(value => value: java.lang.String))(
        _.ipv6Address
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkInterfaceIpv6Address.ReadOnly =
    zio.aws.ec2.model.NetworkInterfaceIpv6Address.wrap(buildAwsValue())
}
object NetworkInterfaceIpv6Address {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkInterfaceIpv6Address =
      zio.aws.ec2.model
        .NetworkInterfaceIpv6Address(ipv6Address.map(value => value))
    def ipv6Address: Option[String]
    def getIpv6Address: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipv6Address", ipv6Address)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
  ) extends zio.aws.ec2.model.NetworkInterfaceIpv6Address.ReadOnly {
    override val ipv6Address: Option[String] =
      scala.Option(impl.ipv6Address()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
  ): zio.aws.ec2.model.NetworkInterfaceIpv6Address.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.20.17.1-sources.jar: zio/aws/ec2/model/NetworkInterfaceIpv6Address.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class NetworkInterfaceIpv6Address(
    ipv6Address: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address = {
    import NetworkInterfaceIpv6Address.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
      .builder()
      .optionallyWith(ipv6Address.map(value => value: java.lang.String))(
        _.ipv6Address
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkInterfaceIpv6Address.ReadOnly =
    zio.aws.ec2.model.NetworkInterfaceIpv6Address.wrap(buildAwsValue())
}
object NetworkInterfaceIpv6Address {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkInterfaceIpv6Address =
      zio.aws.ec2.model
        .NetworkInterfaceIpv6Address(ipv6Address.map(value => value))
    def ipv6Address: Optional[String]
    def getIpv6Address: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipv6Address", ipv6Address)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
  ) extends zio.aws.ec2.model.NetworkInterfaceIpv6Address.ReadOnly {
    override val ipv6Address: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.ipv6Address())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkInterfaceIpv6Address
  ): zio.aws.ec2.model.NetworkInterfaceIpv6Address.ReadOnly = new Wrapper(impl)
}
